@@ -3,6 +3,7 @@ import sys
 from libs.parse import parse_cl
 from preparedata import prepare
 from makecluster import cluster
+from explore_cluster import explore
 import libs.logger as mylog
 import time
 
@@ -13,10 +14,12 @@ def main(**kwargs):
     logger = mylog.getLogger(__name__)
     start = time.time()
     if "prepare" in kwargs:
-		logger.info("Run prepare")
-		prepare(kwargs["args"])
+        logger.info("Run prepare")
+        prepare(kwargs["args"])
     elif "cluster" in kwargs:
-		logger.info("Run cluster")
-		cluster(kwargs["args"])
+        logger.info("Run cluster")
+        cluster(kwargs["args"])
+    elif "explore" in kwargs:
+        logger.info("Run explore")
+        explore(kwargs["args"])
     logger.info('It took %.3f minutes' % ((time.time()-start)/60))
-
